Scroll Area Example
===============================================================================

:download:`scroll_area.enaml <../../../examples/containers/scroll_area.enaml>`

.. literalinclude:: ../../../examples/containers/scroll_area.enaml
    :language: python

::

 $ enaml-run scroll_area.enaml

.. image:: images/scroll_area0.png

.. image:: images/scroll_area1.png

.. image:: images/scroll_area2.png
